@@ -2,11 +2,17 @@ from typing import Any
 from typing import List
 from typing import Optional
 
+from cryptojwt import as_unicode
 from cryptojwt.utils import as_bytes
 from cryptojwt.utils import importer
 from cryptojwt.utils import qualified_name
 
 from oidcmsg.message import Message
+from oidcmsg.storage import DictType
+
+
+def fully_qualified_name(cls):
+    return cls.__module__ + "." + cls.__class__.__name__
 
 
 class ImpExp:
@@ -20,9 +26,18 @@ class ImpExp:
     def dump_attr(self, cls, item, exclude_attributes: Optional[List[str]] = None) -> dict:
         if cls in [None, 0, "", [], {}, bool, b'']:
             if cls == b'':
-                val = as_bytes(item)
+                val = as_unicode(item)
             else:
                 val = item
+        elif cls == "DICT_TYPE":
+            if isinstance(item, dict):
+                val = item
+            else:
+                if isinstance(item, DictType):  # item should be a class instance
+                    val = {
+                        "DICT_TYPE": {"class": fully_qualified_name(item), "kwargs": item.kwargs}}
+                else:
+                    raise ValueError("Expected a DictType class")
         elif isinstance(item, Message):
             val = {qualified_name(item.__class__): item.to_dict()}
         elif cls == object:
@@ -47,10 +62,14 @@ class ImpExp:
 
             info[attr] = self.dump_attr(cls, item, exclude_attributes)
 
-        for attr, d in self.special_load_dump.items():
+        for attr, func in self.special_load_dump.items():
             item = getattr(self, attr, None)
             if item:
-                info[attr] = d["dump"](item, exclude_attributes=exclude_attributes)
+                if "dump" in func:
+                    info[attr] = func["dump"](item, exclude_attributes=exclude_attributes)
+                else:
+                    cls = self.parameter[attr]
+                    info[attr] = self.dump_attr(cls, item, exclude_attributes)
 
         return info
 
@@ -79,6 +98,12 @@ class ImpExp:
                 val = as_bytes(item)
             else:
                 val = item
+        elif cls == "DICT_TYPE":
+            if list(item.keys()) == ["DICT_TYPE"]:
+                _spec = item["DICT_TYPE"]
+                val = importer(_spec["class"])(**_spec["kwargs"])
+            else:
+                val = item
         elif cls == object:
             val = importer(item)
         elif isinstance(cls, list):
@@ -127,7 +152,11 @@ class ImpExp:
 
         for attr, func in self.special_load_dump.items():
             if attr in item:
-                setattr(self, attr, func["load"](item[attr], **_kwargs))
+                if "load" in func:
+                    setattr(self, attr, func["load"](item[attr], **_kwargs))
+                else:
+                    cls = self.parameter[attr]
+                    setattr(self, attr, self.load_attr(cls, item[attr], **_kwargs))
 
         self.local_load_adjustments(**_load_args)
         return self
