@@ -1,20 +1,19 @@
 import logging
 import os
 import time
-from urllib.parse import quote_plus
+from typing import Optional
 
+from cryptojwt.utils import importer
 from filelock import FileLock
 
-from . import Storage
-from .converter import PassThru
-from .converter import QPKey
-from .extension import key_label
-from .utils import importer
+from oidcmsg.storage import DictType
+from oidcmsg.util import PassThru
+from oidcmsg.util import QPKey
 
 logger = logging.getLogger(__name__)
 
 
-class AbstractFileSystem(Storage):
+class AbstractFileSystem(DictType):
     """
     FileSystem implements a simple file based database.
     It has a dictionary like interface.
@@ -24,10 +23,10 @@ class AbstractFileSystem(Storage):
     Not directories in directories.
     """
 
-    def __init__(
-        self,
-        conf_dict,
-    ):
+    def __init__(self,
+                 fdir: Optional[str] = '',
+                 key_conv: Optional[str] = '',
+                 value_conv: Optional[str] = ''):
         """
         items = FileSystem(
             {
@@ -36,34 +35,26 @@ class AbstractFileSystem(Storage):
                 'value_conv':{'to': keyjar_to_jwks, 'from': jwks_to_keyjar}
             })
 
-        fdir: The root of the directory
-        key_conv: Converts to/from the key displayed by this class to
+        :param fdir: The root of the directory
+        :param key_conv: Converts to/from the key displayed by this class to
             users of it to something that can be used as a file name.
             The value of key_conv is a class that has the methods 'serialize'/'deserialize'.
-        value_conv: As with key_conv you can convert/translate
+        :param value_conv: As with key_conv you can convert/translate
             the value bound to a key in the database to something that can easily
             be stored in a file. Like with key_conv the value of this parameter
             is a class that has the methods 'serialize'/'deserialize'.
         """
+        super(AbstractFileSystem, self).__init__(fdir=fdir, key_conv=key_conv, value_conv=value_conv)
 
-        super().__init__(conf_dict)
-        self.config = conf_dict
-
-        _fdir = conf_dict.get("fdir", ".")
-        if "issuer" in conf_dict:
-            _fdir = os.path.join(_fdir, quote_plus(conf_dict["issuer"]))
-
-        self.fdir = _fdir
+        self.fdir = fdir
         self.fmtime = {}
         self.storage = {}
 
-        key_conv = conf_dict.get("key_conv")
         if key_conv:
             self.key_conv = importer(key_conv)()
         else:
             self.key_conv = QPKey()
 
-        value_conv = conf_dict.get("value_conv")
         if value_conv:
             self.value_conv = importer(value_conv)()
         else:
@@ -88,18 +79,14 @@ class AbstractFileSystem(Storage):
         :return:
         """
         item = self.key_conv.serialize(item)
-        fname = os.path.join(self.fdir, item)
-        if self._is_file(fname):
-            lock = FileLock("{}.lock".format(fname))
-            with lock:
-                if self.is_changed(item, fname):
-                    logger.info("File content change in {}".format(item))
-                    self.storage[item] = self._read_info(fname)
 
-            logger.debug('Read from "%s"', item)
-            return self.storage[item]
-        else:
-            raise KeyError(item)
+        if self.is_changed(item):
+            logger.info("File content change in {}".format(item))
+            fname = os.path.join(self.fdir, item)
+            self.storage[item] = self._read_info(fname)
+
+        logger.debug('Read from "%s"', item)
+        return self.storage[item]
 
     def __setitem__(self, key, value):
         """
@@ -121,9 +108,9 @@ class AbstractFileSystem(Storage):
             _key = key
 
         fname = os.path.join(self.fdir, _key)
-        lock = FileLock("{}.lock".format(fname))
+        lock = FileLock('{}.lock'.format(fname))
         with lock:
-            with open(fname, "w") as fp:
+            with open(fname, 'w') as fp:
                 fp.write(self.value_conv.serialize(value))
 
         self.storage[_key] = value
@@ -133,7 +120,7 @@ class AbstractFileSystem(Storage):
     def __delitem__(self, key):
         fname = os.path.join(self.fdir, key)
         if os.path.isfile(fname):
-            lock = FileLock("{}.lock".format(fname))
+            lock = FileLock('{}.lock'.format(fname))
             with lock:
                 os.unlink(fname)
 
@@ -168,43 +155,44 @@ class AbstractFileSystem(Storage):
 
         return mtime
 
-    def _is_file(self, fname):
-        return os.path.isfile(fname)
-
-    def is_changed(self, item, fname):
+    def is_changed(self, item):
         """
-        Find out if this item has been modified since last.
-        When I get here I know that item points to an existing file.
+        Find out if this item has been modified since last
 
         :param item: A key
         :return: True/False
         """
-        mtime = self.get_mtime(fname)
+        fname = os.path.join(self.fdir, item)
+        if os.path.isfile(fname):
+            mtime = self.get_mtime(fname)
 
-        try:
-            _ftime = self.fmtime[item]
-        except KeyError:  # Never been seen before
-            self.fmtime[item] = mtime
-            return True
+            try:
+                _ftime = self.fmtime[item]
+            except KeyError:  # Never been seen before
+                self.fmtime[item] = mtime
+                return True
 
-        if mtime > _ftime:  # has changed
-            self.fmtime[item] = mtime
-            return True
+            if mtime > _ftime:  # has changed
+                self.fmtime[item] = mtime
+                return True
+            else:
+                return False
         else:
-            return False
+            logger.error('Could not access {}'.format(fname))
+            raise KeyError(item)
 
     def _read_info(self, fname):
         if os.path.isfile(fname):
             try:
-                lock = FileLock("{}.lock".format(fname))
+                lock = FileLock('{}.lock'.format(fname))
                 with lock:
-                    info = open(fname, "r").read().strip()
+                    info = open(fname, 'r').read().strip()
                 return self.value_conv.deserialize(info)
             except Exception as err:
                 logger.error(err)
                 raise
         else:
-            logger.error("No such file: {}".format(fname))
+            logger.error('No such file: {}'.format(fname))
         return None
 
     def synch(self):
@@ -220,18 +208,18 @@ class AbstractFileSystem(Storage):
 
             if not os.path.isfile(fname):
                 continue
-            if fname.endswith(".lock"):
+            if fname.endswith('.lock'):
                 continue
 
             if f in self.fmtime:
-                if self.is_changed(f, fname):
+                if self.is_changed(f):
                     self.storage[f] = self._read_info(fname)
             else:
                 mtime = self.get_mtime(fname)
                 try:
                     self.storage[f] = self._read_info(fname)
                 except Exception as err:
-                    logger.warning("Bad content in {} ({})".format(fname, err))
+                    logger.warning('Bad content in {} ({})'.format(fname, err))
                 else:
                     self.fmtime[f] = mtime
 
@@ -260,6 +248,8 @@ class AbstractFileSystem(Storage):
         Replaces what's in the database with a set of key, value pairs.
         Only data bound to keys that appear in ava will be affected.
 
+        Implements the dict.update() method
+
         :param ava: Dictionary
         """
         for key, val in ava.items():
@@ -284,79 +274,18 @@ class AbstractFileSystem(Storage):
 
             if not os.path.isfile(fname):
                 continue
-            if fname.endswith(".lock"):
+            if fname.endswith('.lock'):
                 continue
 
             n += 1
         return n
 
     def __str__(self):
-        return "{config:" + str(self.config) + ", info:" + str(self.storage) + "}"
+        return '{config:' + str(self.config) + ', info:' + str(self.storage) + '}'
 
+    def dump(self):
+        return {k: v for k, v in self.items()}
 
-class LabeledAbstractFileSystem(Storage):
-    def __init__(self, conf_dict, label=""):
-        _conf = {k: v for k, v in conf_dict.items() if k != "label"}
-        Storage.__init__(self, conf_dict=_conf)
-
-        self.storage = AbstractFileSystem(conf_dict)
-        _label = label or conf_dict.get("label", "")
-
-        if not _label:
-            self.label = ""
-        else:
-            self.label = "__{}__".format(_label)
-
-    @key_label
-    def get(self, k, default=None):
-        return self.storage.get(k, default)
-
-    @key_label
-    def update(self, ava):
-        return self.storage.update(ava)
-
-    @key_label
-    def __getitem__(self, k):
-        return self.storage.get(k)
-
-    @key_label
-    def __setitem__(self, k, v):
-        self.storage[k] = v
-
-    @key_label
-    def __delitem__(self, k):
-        del self.storage[k]
-
-    @key_label
-    def __contains__(self, k):
-        return self.storage.__contains__(k)
-
-    def __iter__(self):
-        for key, val in self.storage.__iter__():
-            if key.startswith(self.label):
-                yield key[len(self.label) :], val
-
-    def keys(self):
-        return [k[len(self.label) :] for k in self.storage.keys() if k.startswith(self.label)]
-
-    def items(self):
-        for key, val in self.storage.__iter__():
-            if key.startswith(self.label):
-                yield key[len(self.label) :], val
-
-    def __len__(self):
-        if not os.path.isdir(self.storage.fdir):
-            return 0
-
-        n = 0
-        for f in os.listdir(self.storage.fdir):
-            if f.startswith(self.label):
-                fname = os.path.join(self.storage.fdir, f)
-
-                if not os.path.isfile(fname):
-                    continue
-                if fname.endswith(".lock"):
-                    continue
-
-                n += 1
-        return n
+    def load(self, info):
+        for k, v in info.items():
+            self[k] = v
